Kmultparallel: Parallel implementation of Adams' Kmult (defunct)

View source: R/Kmultparallel.R

KmultparallelR Documentation

Parallel implementation of Adams' Kmult (defunct)

Description

**Defunct**: This function has been removed from the package. Please use geomorph::physignal() instead.

Usage

Kmultparallel(data, trees, burninpercent = 0, iter = 0, verbose = TRUE)

Arguments

data

Ignored (function is defunct).

trees

Ignored (function is defunct).

burninpercent

Ignored (function is defunct).

iter

Ignored (function is defunct).

verbose

Ignored (function is defunct).

Value

Does not return; always signals a defunct error.

References

Adams DC. 2014. A Generalized K Statistic for Estimating Phylogenetic Signal from Shape and Other High-Dimensional Multivariate Data. Systematic Biology 63:685-697.

Fruciano C, Celik MA, Butler K, Dooley T, Weisbecker V, Phillips MJ. 2017. Sharing is caring? Measurement error and the issues arising from combining 3D morphometric datasets. Ecology and Evolution 7:7034-7046.


GeometricMorphometricsMix documentation built on April 18, 2026, 1:06 a.m.