arching_vector: Body arching vector from brown trout study

arching_vectorR Documentation

Body arching vector from brown trout study

Description

A list containing the body arching vector obtained using common principal components following the procedure described in Fruciano et al. 2020, and the GPA consensus used to align individual models when the vector was computed. The GPA consensus is provided to align new data using the same consensus), but using the consensus for downstream work is not recommended.

Usage

data(arching_vector)

Format

A list with two components as described above.

Details

The object is a list with the following elements:

GPA_consensus_used

A matrix of landmark coordinates for the GPA consensus to which the models have been aligned (brown trout dataset in this package)

arching_vector_CPCA

A numeric vector of shape change obtained using common principal component analysis as detailed in Fruciano et al. 2020.

References

Fruciano C., Schmidt, I., Ramirez Sanchez, M.M., Morek, W., Avila Valle, Z.A., Talijancic, I., Pecoraro, C., Schermann Legionnet, A. 2020. Tissue preservation can affect geometric morphometric analyses: a case study using fish body shape. Zoological Journal of the Linnean Society 188:148-162.

See Also

ProjectOrthogonal for projection/removal of an effect

Examples

data(arching_vector)
a = arching_vector
names(a)
dim(a$GPA_consensus_used)
length(a$arching_vector_CPCA)

GeometricMorphometricsMix documentation built on April 18, 2026, 1:06 a.m.