View source: R/EscoufierRVrarefy.R
| plot.EscoufierRVrarefy | R Documentation |
Creates a confidence interval plot for RV rarefaction results
## S3 method for class 'EscoufierRVrarefy'
plot(x, point_color = "darkblue", errorbar_color = "darkred", ...)
x |
An object of class "EscoufierRVrarefy" |
point_color |
A single color or a vector of colors for point estimates. If length 1, the same color is used for all points. If length equals the number of groups, colors are assigned per group. (default "darkblue") |
errorbar_color |
A single color or a vector of colors for error bars. Follows the same recycling rules as 'point_color'. (default "darkred") |
... |
Additional arguments passed to the underlying plotting function |
A ggplot object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.