Convenience function which rescales a dataset of landmarks based on a vector of distances between two landmarks
rescale_by_landmark_distance(Data, lm1, lm2, lengths)The function outputs an array k x p x n of rescaled landmark coordinates
array k x p x n of k landmarks and p dimensions for n observations (specimens)
index of the two landmarks whose inter-landmark distance is known
vector of n lengths (distances between lm1 and lm2 in the appropriate scale)
This function can be useful when one has the distance between two landmarks (e.g., obtained with a caliper), but a scale has not been set when acquiring the data (for instance, a scale bar was missing on photos, so configuration of landmarks are scaled in pixels).